web2ldap is known to work smoothly with the software/platforms mentioned here. If a software is not listed here does not mean it is not compatible unless it is listed in the negative list.

[LDAP servers] [Web browsers] [Operating systems] [Web servers]

# LDAP Servers

Please note that support for LDAPv2 connections was dropped in release 1.1.5 since this is considered historic since a quite while now (see also RFC 3494).

Server product | Tested releases | Comments | Current Status
--- | --- | --- | ---
OpenLDAP | 2.x | Open Source reference implementation of LDAPv3. web2ldap has some extra features for this server. | Regularly used for interop tests.
OpenDJ | 2.4.x | ForgeRock's fork of OpenDS which works just fine. Especially using more sophisticated LDAPv3 extended controls has been tested with this. Used for interop testing of DIT structure rules and name forms. | Regularly used for interop tests.
MS Active Directory | W2K, W2K3, W2K3R2, W2K8, W2K8R2, W2K12 | Various work-arounds were added to handle the broken sub schema in W2K. Some extra features were added for MS AD. | W2K3+ regularly used for interop tests.
389 also known as Fedora Directory Server | recent | Seems to work but has subschema bugs with non-unique NAMEs and/or OIDs which requires to set schema_strictcheck=False. | Tested occasionally, accessible in online demo.
CA eTrust Directory | 8.1 and 12.0 | Worked just fine. Release 8.1 used as reference server for implementing the viewer for DIT structure rules and name forms in web2ldap. | Not tested for a while.
Novell eDirectory | 8.7.x and 8.8.x | Ships with broken schema (non-unique OIDs) but recent web2ldap versions have work-arounds for this. | Not tested for a while.
Netscape Directory Server | 4.x | Used to work just fine but not tested for a while. | Historic
iPlanet/SunONE Directory Server | 5.x and 6.x | Seems to work but has subschema bugs with non-unique NAMEs and/or OIDs which requires to set schema_strictcheck=False. | Tested rather rarely
Oracle DSEE (formerly Sun) | 11.1.1.7.2 | Seems to work but has subschema bugs with non-unique NAMEs and/or OIDs which requires to set schema_strictcheck=False. | Tested rather rarely (last time 04/2015)
Lotus Domino LDAP | R5.x, R6.x and R7.0.x | Most times it works quite well. Persistent connections are dropped very fast - depends on the version I guess. web2ldap contains a work-around for the null-byte terminated string of the namingContexts attribute in Domino/LDAP's RootDSE. | Tested rather rarely (last time 7.03)
Siemens DirX | 6.x | Worked just fine. Added support in web2ldap for searching the administrative sub entries. | Not tested for a while.
Innosoft Distributed Directory Server (IDDS) | unknown version | Only read-only tests were done and the product is not available anymore for years. | Historic
Critical Path InJoin and Directory Server 4.2 | 4.x | Worked without problems. | Not tested for a while.
Syntegra | unknown version | Read-only tests on a public address book server worked. | Historic.
IBM Directory Server | unknown version | Worked without problems. | Not tested for a while.
Apache DS | 1.5 and 2.0M7 | Simple operations have been reported to work just fine. Recent 2.0M7 caused interop problems with invalid password policy response control. | Tested rarely.
OpenDS | 1.0 and 2.0RC | Worked just fine also with DIT structure rules and name forms. | Not tested for a while since project seems dead.
Isode's M-Vault LDAP/X.500 Directory Server | R14 | Some glitches were resolved in web2ldap 1.0.7 to work with the M-Vault Directory Server. | Not tested for a while.
ViewDS (formerly View500) | 6.0e11 | Works also with DIT structure rules and name forms. web2ldap honors the operational attribute governingStructureRule. | Not tested for a while.

# Web Browsers

Viewable With Any Browser!

Mozilla
  Mozilla 1.x already had very good CSS support.
  Recent versions of Firefox and Seamonkey simply work and are used as a reference.
Konqueror
  The web browser and file manager of the KDE project: Note the input forms enclosed in <fieldset> were not displayed by older versions. (see KDE bug #44643 RESOLVED).
Microsoft Internet Explorer
  Support for CSS depends very much on the version used. The modern CSS files shipped with web2ldap likely does not work with IE 6.0 and before. Some minor CSS glitches with IE 7.0.
Opera
  Commercial browser. Aims to be fast and small. Also very good CSS support.
Google Chrome
  Simply works.
lynx
  A text-mode browser - still supported for those who have to use a terminal.
w3m
  Another text-mode browser capable of handling tables and displaying images (if the terminal allows it).

# Operating Systems

Linux
  Please do not use outdated OS packages.
FreeBSD
  There is a FreeBSD port of web2ldap.
OpenBSD
  There is a OpenBSD port of web2ldap.

# Web Servers

Apache httpd
  I don't have to write any explanation about this one...
UWSGI
  several modes possible, e.g. integrated via Apache httpd via mod_proxy_uwsgi
gunicorn
  also used within Æ-DIR configuration via Apache httpd with mod_proxy_http
lighttpd
  ***TO-DO: Update for WSGI***
nginx
  ***TO-DO: Update for WSGI***